@@ -8,60 +8,60 @@
 #' RCAR+ extends RCAR from a binary classifier to a multi-class classifier
 #' using regularized multinomial logistic regression via \pkg{glmnet}.
 #'
-#' If lambda is not specified (\code{NULL}) then cross-validation with the
+#' If lambda is not specified (`NULL`) then cross-validation with the
 #' largest value of lambda such that error is within 1 standard error of the
-#' minimum is used to determine the best value (see \code{\link{cv.glmnet}}).
-#'
-#' See \code{\link{cv.glmnet}} for performing cross-validation in parallel.
+#' minimum is used to determine the best value (see [cv.glmnet()] also for how to
+#' perform cross-validation in parallel).
 #'
 #' @aliases RCAR rcar
+#'
 #' @param formula A symbolic description of the model to be fitted. Has to be
-#' of form \code{class ~ .} or \code{class ~ predictor1 + predictor2}.
-#' @param data A data.frame containing the training data.
+#'   of form `class ~ .` or `class ~ predictor1 + predictor2`.
+#' @param data A data.frame or [arules::transactions] containing the training data.
+#'   Data frames are automatically discretized and converted to transactions with
+#'   [prepareTransactions()].
 #' @param lambda The amount of weight given to regularization during the
-#' logistic regression learning process. If not specified (\code{NULL}) then
-#' cross-validation is used to determine the best value (see Details section).
-#' @param alpha The elastic net mixing parameter. \code{alpha = 1} is the lasso
-#' penalty (default RCAR), and \code{alpha = 0} the ridge penalty.
+#'   logistic regression learning process. If not specified (`NULL`) then
+#'   cross-validation is used to determine the best value (see Details section).
+#' @param alpha The elastic net mixing parameter. `alpha = 1` is the lasso
+#'   penalty (default RCAR), and `alpha = 0` the ridge penalty.
 #' @param cv.glmnet.args,glmnet.args A list of arguments passed on to
-#' \code{\link[glmnet]{cv.glmnet}} and \code{\link[glmnet]{glmnet}},
-#' respectively. See Example section.
-#' @param parameter,control Optional parameter and control lists for apriori.
-#' @param balanceSupport balanceSupport parameter passed to
-#' \code{\link{mineCARs}} function.
+#'   [cv.glmnet()] and [glmnet()], respectively. See Example section.
+#' @param parameter,control Optional parameter and control lists for [apriori()].
+#' @param balanceSupport balanceSupport parameter passed to [mineCARs()].
 #' @param disc.method Discretization method for factorizing numeric input
-#' (default: \code{"mdlp"}). See \code{\link{discretizeDF.supervised}} for more
-#' supervised discretization methods.
+#'   (default: `"mdlp"`). See [discretizeDF.supervised()] for more
+#'   supervised discretization methods.
 #' @param verbose Report progress?
 #' @param ... For convenience, additional parameters are used to create the
-#' \code{parameter} control list for apriori (e.g., to specify the support and
-#' confidence thresholds).
-#' @return Returns an object of class \code{CBA} representing the trained
-#' classifier with the additional field \code{model} containing a list with the
-#' following elements:
+#' \code{parameter} control list for [apriori()] (e.g., to specify the support and
+#'   confidence thresholds).
+#' @return Returns an object of class [CBA] representing the trained
+#'   classifier with the additional field `model` containing a list with the
+#'   following elements:
 #'
 #' \item{all_rules}{all rules used to build the classifier, including the rules
-#' with a weight of zero.} \item{reg_model}{them multinomial logistic
-#' regression model as an object of class \code{\link{glmnet}}.}
+#'   with a weight of zero.}
+#' \item{reg_model}{them multinomial logistic
+#'   regression model as an object of class [glmnet()].}
 #' \item{cv}{contains the results for the cross-validation used determine
-#' lambda.}
+#'   lambda.}
 #' @author Tyler Giallanza and Michael Hahsler
-#' @seealso \code{\link{CBA.object}}, \code{\link{mineCARs}},
-#' \code{\link{glmnet}} and \code{\link{cv.glmnet}}.
-#' @references M. Azmi, G.C. Runger, and A. Berrado (2019). Interpretable
+#'
+#' @references
+#' M. Azmi, G.C. Runger, and A. Berrado (2019). Interpretable
 #' regularized class association rules algorithm for classification in a
-#' categorical data space. \emph{Information Sciences,} Volume 483, May 2019.
+#' categorical data space. _Information Sciences,_ Volume 483, May 2019.
 #' Pages 313-331.
 #'
 #' @examples
-#'
 #' data("iris")
 #'
 #' classifier <- RCAR(Species~., iris)
 #' classifier
 #'
 #' # inspect the rule base sorted by the larges class weight
-#' inspect(sort(rules(classifier), by = "weight"))
+#' inspect(sort(classifier$rules, by = "weight"))
 #'
 #' # make predictions for the first few instances of iris
 #' predict(classifier, head(iris))
@@ -74,7 +74,7 @@
 #'
 #' # show progress report and use 5 instead of the default 10 cross-validation folds.
 #' classifier <- RCAR(Species~., iris, cv.glmnet.args = list(nfolds = 5), verbose = TRUE)
-#'
+#' @export
 RCAR <- function(formula,
   data,
   lambda = NULL,
@@ -135,10 +135,10 @@ RCAR <- function(formula,
     model <- cv$glmnet.fit
     best_model <- which.min(abs(model$lambda - lambda))
     weights <- sapply(
-        model$beta,
-        FUN = function(x)
-          as.vector(x[, best_model, drop = FALSE])
-      )
+      model$beta,
+      FUN = function(x)
+        as.vector(x[, best_model, drop = FALSE])
+    )
     bias <- model$a0[, best_model, drop = FALSE]
   } else{
     if (verbose)
@@ -168,13 +168,16 @@ RCAR <- function(formula,
   quality(cars)$weight <- apply(weights, MARGIN = 1, max)
   quality(cars)$oddsratio <- exp(quality(cars)$weight)
   rulebase <- cars[!remove]
-  weights <- weights[!remove, ]
+  weights <- weights[!remove,]
 
   if (verbose)
     cat("* CARs left:", length(rulebase), "\n")
 
   ### default class is used for 0 rules. Use largest bias.
-  default <- factor(unname(which.max(t(bias))), levels = seq_len(nrow(bias)) , labels = rownames(bias))
+  default <-
+    factor(unname(which.max(t(bias))),
+      levels = seq_len(nrow(bias)) ,
+      labels = rownames(bias))
 
   CBA_ruleset(
     formula = formula,
